@@ -3,12 +3,10 @@ from ..scorer.ScorerTF import ScorerTF
 import shutil
 import tensorflow as tf
 import tensorflow.keras as K
-import tensorflow_addons as tfa
 import matplotlib.pyplot as plt
 import numpy as np
 import io
 
-
 from ..DataSet import TrainingSet
 from ..Model import Model
 
@@ -37,6 +35,14 @@ class ModelKerasAdapter(Model):
         prepend = "val_" if validation else ""
         return prepend + metric["name"]
 
+    def getMetrics(self):
+        scorer = ScorerTF(self.numClasses)
+        metrics = []
+        for metric in self.validationMetrics:
+            m = scorer.getMetricScorer(metric)
+            metrics.append(m)
+        return metrics
+
     def beforeTrain(self, dataset):
         # from tensorflow.keras.models import load_model
         if "loadModelPath" in self.options:
@@ -109,7 +115,7 @@ class ModelKerasAdapter(Model):
 
         if self.learningRateDecay is not None and self.learningRateDecay > 0:
             lr_decay_cb = K.callbacks.LearningRateScheduler(
-                schedule=lambda epoch: self.learningRate * (self.learningRateDecay ** epoch)
+                schedule=lambda epoch: self.learningRate * (self.learningRateDecay**epoch)
             )
             callbacks.append(lr_decay_cb)
 
@@ -141,6 +147,9 @@ class ModelKerasAdapter(Model):
         # Model for validationdata: self.model(validationData.__next__()[0])
         # Loss (if its not implemented as string!): self.getLossFunction()(train.__next__()[1], self.model(train.__next__()[0]))
         # Test other Loss: tf.keras.losses.BinaryCrossentropy(from_logits=False)(train.__next__()[1], self.model(train.__next__()[0]))
+        # Test Test Scorer
+        # x, y = train.__next__()
+        # ScorerTF(self.numClasses).getMetricScorer("kappa")(y, self.model(x))
         self.model.fit(
             x=train,
             validation_data=validationData,
@@ -163,27 +172,19 @@ class ModelKerasAdapter(Model):
         optimizer = None
         lossFunction = self.getLossFunction()
         lossWeights = self.getLossWeights()
-        metrics = []
 
         if self.optimizer == "adams":
             optimizer = K.optimizers.Adam(learning_rate=self.learningRate)
         if self.optimizer == "nadams":
             optimizer = K.optimizers.Nadam(learning_rate=self.learningRate)
 
-        scorer = ScorerTF(self.numClasses)
-
-        for metric in self.validationMetrics:
-            m = scorer.getMetricScorer(metric)
-            # metrics.append((metric, m))
-            metrics.append(m)
-
         self.model.compile(
             optimizer=optimizer,
             loss=lossFunction,
             loss_weights=lossWeights,
-            metrics=metrics,
-            # run_eagerly=None,  # for debug purpose!
-            run_eagerly=True,  # for debug purpose!
+            metrics=self.getMetrics(),
+            # run_eagerly=None,
+            run_eagerly=True,  # for debug purpose! required for scorer ?
         )
         # for metric in self.validationMetrics:
         # m = scorer.getMetricScorer(metric)
